smartcard.Exceptions.InvalidReaderException

# ``smartcard`.`Exceptions`.`InvalidReaderException``

exception documentation

`class InvalidReaderException(SmartcardException):`

View In Hierarchy

Raised when trying to acces an invalid smartcard reader.

Method | `__init__` | Undocumented

Inherited from `SmartcardException`:

Method | `__str__` | Undocumented
Instance Variable | `hresult` | Undocumented

def __init__(self, readername):
overrides `smartcard.Exceptions.SmartcardException.__init__`

Undocumented